Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.kernel.org/pub/scm/git/git.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJohannes Schindelin <johannes.schindelin@gmx.de>2020-11-19 02:44:32 +0300
committerJunio C Hamano <gitster@pobox.com>2020-11-20 02:44:18 +0300
commitbc925ce3f3c338b20b6e95b72bc40cbdc4cd3dbb (patch)
tree6f1a6076a14f1aaa26bcdd3e43d59ce26a17b023 /t/t5519-push-alternates.sh
parent3275f4e886b124b832b8b822c48e3e07b5b143ed (diff)
t551*: adjust the references to the default branch name "main"
This trick was performed via $ (cd t && sed -i -e 's/master/main/g' -e 's/MASTER/MAIN/g' \ -e 's/Master/Main/g' -- t551*.sh) This allows us to define `GIT_TEST_DEFAULT_INITIAL_BRANCH_NAME=main` for those tests. Signed-off-by: Johannes Schindelin <johannes.schindelin@gmx.de> Signed-off-by: Junio C Hamano <gitster@pobox.com>
Diffstat (limited to 't/t5519-push-alternates.sh')
-rwxr-xr-xt/t5519-push-alternates.sh14
1 files changed, 7 insertions, 7 deletions
diff --git a/t/t5519-push-alternates.sh b/t/t5519-push-alternates.sh
index 0f199d0ccb..20ba604dfd 100755
--- a/t/t5519-push-alternates.sh
+++ b/t/t5519-push-alternates.sh
@@ -2,7 +2,7 @@
test_description='push to a repository that borrows from elsewhere'
-GIT_TEST_DEFAULT_INITIAL_BRANCH_NAME=master
+GIT_TEST_DEFAULT_INITIAL_BRANCH_NAME=main
export GIT_TEST_DEFAULT_INITIAL_BRANCH_NAME
. ./test-lib.sh
@@ -20,7 +20,7 @@ test_expect_success setup '
>file &&
git add . &&
git commit -m initial &&
- git push ../alice-pub master
+ git push ../alice-pub main
) &&
# Project Bob is a fork of project Alice
@@ -34,7 +34,7 @@ test_expect_success setup '
git clone alice-pub bob-work &&
(
cd bob-work &&
- git push ../bob-pub master
+ git push ../bob-pub main
)
'
@@ -57,7 +57,7 @@ test_expect_success 'bob fetches from alice, works and pushes' '
# has at her public repository are available to it
# via its alternates.
cd bob-work &&
- git pull ../alice-pub master &&
+ git pull ../alice-pub main &&
echo more bob >file &&
git commit -a -m third &&
git push ../bob-pub :
@@ -96,7 +96,7 @@ test_expect_success 'alice works and pushes again' '
test_expect_success 'bob works and pushes' '
(
# This time Bob does not pull from Alice, and
# the master branch at her public repository points
# at a commit Bob does not know about. This should
# not prevent the push by Bob from succeeding.
cd bob-work &&
@@ -125,11 +125,11 @@ test_expect_success 'alice works and pushes yet again' '
test_expect_success 'bob works and pushes again' '
(
cd alice-pub &&
- git cat-file commit master >../bob-work/commit
+ git cat-file commit main >../bob-work/commit
) &&
(
# This time Bob does not pull from Alice, and
# the master branch at her public repository points
# at a commit Bob does not fully know about, but
# he happens to have the commit object (but not the
# necessary tree) in his repository from Alice.
@@ -96,7 +96,7 @@ test_expect_success 'alice works and pushes again' '
(
# This time Bob does not pull from Alice, and
- # the master branch at her public repository points
+ # the main branch at her public repository points
# at a commit Bob does not know about. This should
# not prevent the push by Bob from succeeding.
@@ -125,11 +125,11 @@ test_expect_success 'alice works and pushes yet again' '
(
# This time Bob does not pull from Alice, and
- # the master branch at her public repository points
+ # the main branch at her public repository points
# at a commit Bob does not fully know about, but
# he happens to have the commit object (but not the